<?php
if (!defined('ABSPATH')) exit;

// 获取所有分组
global $wpdb;
$groups = $wpdb->get_results(
    "SELECT g.*, COUNT(s.id) as site_count 
    FROM {$wpdb->prefix}jefrss_groups g 
    LEFT JOIN {$wpdb->prefix}jefrss_sites s ON g.id = s.group_id 
    GROUP BY g.id 
    ORDER BY g.order_num"
);
?>

<div class="wrap">
    <h1 class="wp-heading-inline"><?php _e('分组管理', 'jefrssfriend'); ?></h1>
    <button type="button" class="page-title-action add-group-btn">
        <?php _e('添加分组', 'jefrssfriend'); ?>
    </button>
    
    <!-- 遮罩层 -->
    <div id="group-form-overlay" style="display: none;"></div>
    
    <!-- 添加/编辑表单 -->
    <div id="group-form" class="jefrss-form" style="display: none;">
        <form>
            <?php wp_nonce_field('jefrssfriend-admin'); ?>
            <input type="hidden" name="group_id" id="group-id" value="">
            
            <table class="form-table">
                <tr>
                    <th scope="row">
                        <label for="group-name"><?php _e('分组名称', 'jefrssfriend'); ?></label>
                    </th>
                    <td>
                        <input type="text" id="group-name" name="name" class="regular-text" required>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="group-order"><?php _e('排序', 'jefrssfriend'); ?></label>
                    </th>
                    <td>
                        <input type="number" id="group-order" name="order_num" class="small-text" value="0" min="0">
                    </td>
                </tr>
            </table>
            
            <div class="submit-wrapper">
                <button type="button" class="button cancel-btn">
                    <?php _e('取消', 'jefrssfriend'); ?>
                </button>
                <button type="submit" class="button button-primary">
                    <?php _e('保存', 'jefrssfriend'); ?>
                </button>
            </div>
        </form>
    </div>
    
    <!-- 分组列表 -->
    <?php if ($groups): ?>
    <table class="wp-list-table widefat fixed striped">
        <thead>
            <tr>
                <th><?php _e('分组名称', 'jefrssfriend'); ?></th>
                <th><?php _e('RSS源数量', 'jefrssfriend'); ?></th>
                <th><?php _e('排序', 'jefrssfriend'); ?></th>
                <th><?php _e('操作', 'jefrssfriend'); ?></th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($groups as $group): ?>
            <tr>
                <td>
                    <strong><?php echo esc_html($group->name); ?></strong>
                </td>
                <td>
                    <?php echo (int)$group->site_count; ?>
                </td>
                <td>
                    <?php echo (int)$group->order_num; ?>
                </td>
                <td>
                    <button type="button" class="button edit-group" 
                            data-id="<?php echo $group->id; ?>"
                            data-name="<?php echo esc_attr($group->name); ?>"
                            data-order="<?php echo (int)$group->order_num; ?>">
                        <?php _e('编辑', 'jefrssfriend'); ?>
                    </button>
                    <?php if ($group->site_count == 0): ?>
                    <button type="button" class="button delete-group" 
                            data-id="<?php echo $group->id; ?>">
                        <?php _e('删除', 'jefrssfriend'); ?>
                    </button>
                    <?php endif; ?>
                </td>
            </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
    <?php else: ?>
    <p><?php _e('暂无分组，请添加。', 'jefrssfriend'); ?></p>
    <?php endif; ?>
</div>

<style>
/* 弹窗样式 */
#group-form-overlay {
    position: fixed;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    background: rgba(0,0,0,0.5);
    z-index: 999;
}

#group-form {
    position: fixed;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    background: white;
    padding: 20px;
    border-radius: 8px;
    box-shadow: 0 0 10px rgba(0,0,0,0.2);
    z-index: 1000;
    width: 500px;
    max-width: 90%;
}

.submit-wrapper {
    text-align: right;
    margin-top: 20px;
    padding-top: 10px;
    border-top: 1px solid #eee;
}

.submit-wrapper button {
    margin-left: 10px;
}
</style> 