<?php
if (!defined('ABSPATH')) exit;



// 获取文章ID和其他文章列表
$article_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

// 首先获取当前文章
$article = $wpdb->get_row($wpdb->prepare("
    SELECT a.*, s.title as site_title, s.site_url, s.icon_url
    FROM {$wpdb->prefix}jefrss_articles a
    LEFT JOIN {$wpdb->prefix}jefrss_sites s ON a.site_id = s.id
    WHERE a.id = %d
", $article_id));

if (!$article) {
    wp_die(__('文章不存在', 'jefrssfriend'));
}

// 获取同一站点的文章列表
$articles_list = $wpdb->get_results($wpdb->prepare("
    SELECT a.id, a.title, a.pub_date, a.link, s.title as site_title, s.icon_url
    FROM {$wpdb->prefix}jefrss_articles a
    LEFT JOIN {$wpdb->prefix}jefrss_sites s ON a.site_id = s.id
    WHERE a.site_id = %d
    ORDER BY a.pub_date DESC
    LIMIT 20
", $article->site_id));

// 获取上一篇文章
$prev_article = $wpdb->get_row($wpdb->prepare("
    SELECT a.id, a.title 
    FROM {$wpdb->prefix}jefrss_articles a
    WHERE a.site_id = %d 
    AND a.pub_date > %s
    ORDER BY a.pub_date ASC 
    LIMIT 1
", $article->site_id, $article->pub_date));

// 获取下一篇文章
$next_article = $wpdb->get_row($wpdb->prepare("
    SELECT a.id, a.title 
    FROM {$wpdb->prefix}jefrss_articles a
    WHERE a.site_id = %d 
    AND a.pub_date < %s
    ORDER BY a.pub_date DESC 
    LIMIT 1
", $article->site_id, $article->pub_date));

// 在获取文章后添加调试信息
if ($article) {
    error_log('Article content length: ' . strlen($article->content));
    error_log('Article content preview: ' . substr($article->content, 0, 100));
}
?>

<div class="wrap">
    <div class="reader-center">
        <!-- 左侧文章列表 -->
        <div class="articles-list">
            <div class="list-header">
                <h2><?php _e('最新文章', 'jefrssfriend'); ?></h2>
            </div>
            <div class="list-content">
                <?php foreach ($articles_list as $list_item): ?>
                <a href="<?php echo admin_url('admin.php?page=jefrssfriend-reader&id=' . $list_item->id); ?>" 
                   class="article-item <?php echo ($list_item->id == $article_id) ? 'active' : ''; ?>">
                    <div class="article-meta">
                        <img class="site-icon" 
                             src="<?php echo esc_url($list_item->icon_url ? $list_item->icon_url : jefrssfriend_get_icon_service_url(parse_url($list_item->link, PHP_URL_HOST))); ?>" 
                             alt="<?php echo esc_attr($list_item->site_title); ?>">
                        <span class="site-title"><?php echo esc_html($list_item->site_title); ?></span>
                        <time><?php echo human_time_diff(strtotime($list_item->pub_date)) . __('前', 'jefrssfriend'); ?></time>
                    </div>
                    <h3 class="article-title">
                        <?php echo esc_html($list_item->title); ?>
                    </h3>
                </a>
                <?php endforeach; ?>
            </div>
        </div>

        <!-- 右侧阅读区域 -->
        <div class="reader-content">
            <!-- 文章内容... -->
        </div>
    </div>
</div>

<!-- 添加JavaScript -->
<script>
document.addEventListener('DOMContentLoaded', function() {
    // 夜间模式切换
    const toggleDarkMode = document.querySelector('.toggle-dark-mode');
    if (toggleDarkMode) {
        toggleDarkMode.addEventListener('click', function() {
            document.body.classList.toggle('dark-mode');
            localStorage.setItem('jefrss_dark_mode', document.body.classList.contains('dark-mode'));
        });
        
        // 检查本地存储的夜间模式状态
        if (localStorage.getItem('jefrss_dark_mode') === 'true') {
            document.body.classList.add('dark-mode');
        }
    }
    
    // 处理图片点击放大
    const images = document.querySelectorAll('.reader-content img');
    images.forEach(img => {
        img.addEventListener('click', function() {
            this.classList.toggle('expanded');
        });
    });
    
    // 滚动时固定左侧边栏
    const sidebar = document.querySelector('.articles-sidebar');
    const sidebarTop = sidebar.offsetTop;
    
    window.addEventListener('scroll', () => {
        if (window.pageYOffset >= sidebarTop) {
            sidebar.classList.add('fixed');
        } else {
            sidebar.classList.remove('fixed');
        }
    });
});
</script> 