<?php
if (!defined('ABSPATH')) exit;

// 获取所有分组
global $wpdb;
$groups = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}jefrss_groups ORDER BY order_num");

// 分页设置
$per_page = 40; // 每页显示数量
$current_page = isset($_GET['paged']) ? max(1, intval($_GET['paged'])) : 1;
$offset = ($current_page - 1) * $per_page;

// 获取总记录数
$total_items = $wpdb->get_var("
    SELECT COUNT(DISTINCT s.id) 
    FROM {$wpdb->prefix}jefrss_sites s
");

// 计算总页数
$total_pages = ceil($total_items / $per_page);

// 获取站点列表
$sites = $wpdb->get_results($wpdb->prepare("
    SELECT DISTINCT 
        s.*, 
        g.name as group_name,
        (SELECT MAX(pub_date) 
         FROM {$wpdb->prefix}jefrss_articles 
         WHERE site_id = s.id) as last_fetch
    FROM {$wpdb->prefix}jefrss_sites s
    LEFT JOIN {$wpdb->prefix}jefrss_groups g ON s.group_id = g.id
    ORDER BY s.title ASC
    LIMIT %d OFFSET %d
", $per_page, $offset));

?>

<div class="wrap">
    <h1><?php _e('站点管理', 'jefrssfriend'); ?></h1>
    
    <!-- 添加按钮 -->
    <button type="button" class="page-title-action add-site-btn">
        <?php _e('添加RSS源', 'jefrssfriend'); ?>
    </button>
    
    <!-- 调试信息 -->
    <div id="debug-info" style="display:none;">
        <pre></pre>
    </div>
    
    <!-- 遮罩层 -->
    <div id="form-overlay" style="
        display: none;
        position: fixed;
        top: 0;
        left: 0;
        right: 0;
        bottom: 0;
        background: rgba(0,0,0,0.5);
        z-index: 999;">
    </div>
    
    <!-- 添加/编辑表单 -->
    <div id="site-form" class="jefrss-form" style="
        display: none;
        position: fixed;
        top: 50%;
        left: 50%;
        transform: translate(-50%, -50%);
        background: white;
        padding: 20px;
        border-radius: 8px;
        box-shadow: 0 0 10px rgba(0,0,0,0.2);
        z-index: 1000;
        max-width: 600px;
        width: 90%;
        max-height: 90vh;
        overflow-y: auto;">
        
        <!-- 关闭按钮 -->
        <button type="button" class="close-form" style="
            position: absolute;
            right: 10px;
            top: 10px;
            background: none;
            border: none;
            cursor: pointer;
            font-size: 20px;
            color: #666;">×</button>
        
        <form method="post" action="" id="add-site-form">
            <?php wp_nonce_field('jefrssfriend-admin'); ?>
            <input type="hidden" name="site_id" id="site-id" value="">
            
            <table class="form-table">
                <tr>
                    <th scope="row">
                        <label for="site-title"><?php _e('站点名称', 'jefrssfriend'); ?></label>
                    </th>
                    <td>
                        <input type="text" id="site-title" name="title" class="regular-text" required>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="rss-url"><?php _e('RSS地址', 'jefrssfriend'); ?></label>
                    </th>
                    <td>
                        <input type="url" id="rss-url" name="rss_url" class="regular-text" required>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="site-url"><?php _e('站点地址', 'jefrssfriend'); ?></label>
                    </th>
                    <td>
                        <input type="url" id="site-url" name="site_url" class="regular-text">
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="group-id"><?php _e('所属分组', 'jefrssfriend'); ?></label>
                    </th>
                    <td>
                        <select id="group-id" name="group_id" class="regular-text">
                            <option value="0"><?php _e('未分组', 'jefrssfriend'); ?></option>
                            <?php foreach ($groups as $group): ?>
                            <option value="<?php echo $group->id; ?>">
                                <?php echo esc_html($group->name); ?>
                            </option>
                            <?php endforeach; ?>
                        </select>
                    </td>
                </tr>
            </table>
            
            <p class="submit">
                <button type="submit" class="button button-primary"><?php _e('保存', 'jefrssfriend'); ?></button>
                <button type="button" class="button close-form"><?php _e('取消', 'jefrssfriend'); ?></button>
            </p>
        </form>
    </div>
    
    <!-- 站点列表 -->
    <?php if ($sites): ?>
    <table class="wp-list-table widefat fixed striped">
        <thead>
            <tr>
                <th class="column-icon"></th>
                <th><?php _e('站点名称', 'jefrssfriend'); ?></th>
                <th><?php _e('RSS地址', 'jefrssfriend'); ?></th>
                <th><?php _e('分组', 'jefrssfriend'); ?></th>
                <th><?php _e('最后更新', 'jefrssfriend'); ?></th>
                <th><?php _e('状态', 'jefrssfriend'); ?></th>
                <th><?php _e('操作', 'jefrssfriend'); ?></th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($sites as $site): ?>
            <tr>
                <td class="column-icon">
                    <img src="<?php echo esc_url(jefrssfriend_get_site_icon($site)); ?>" 
                         class="site-icon" 
                         alt="<?php echo esc_attr($site->title); ?>">
                </td>
                <td>
                    <?php echo esc_html($site->title); ?>
                </td>
                <td>
                    <a href="<?php echo esc_url($site->rss_url); ?>" target="_blank">
                        <?php echo esc_url($site->rss_url); ?>
                    </a>
                </td>
                <td>
                    <?php echo $site->group_name ? 
                        esc_html($site->group_name) : 
                        __('未分组', 'jefrssfriend'); ?>
                </td>
                <td>
                    <?php 
                    if ($site->last_fetch) {
                        echo human_time_diff(strtotime($site->last_fetch)) . __('前', 'jefrssfriend');
                    } else {
                        echo '<span class="no-fetch">' . __('从未', 'jefrssfriend') . '</span>';
                    }
                    ?>
                </td>
                <td>
                    <span class="status-<?php echo $site->status; ?>">
                        <?php echo $site->status === 'active' ? 
                            __('正常', 'jefrssfriend') : 
                            __('停用', 'jefrssfriend'); ?>
                    </span>
                </td>
                <td class="column-actions">
                    <button type="button" class="button refresh-site" data-id="<?php echo $site->id; ?>" title="<?php _e('刷新订阅', 'jefrssfriend'); ?>">
                        <?php _e('刷新', 'jefrssfriend'); ?>
                    </button>
                    <button type="button" class="button edit-site" 
                        data-id="<?php echo $site->id; ?>"
                        data-title="<?php echo esc_attr($site->title); ?>"
                        data-rss-url="<?php echo esc_url($site->rss_url); ?>"
                        data-site-url="<?php echo esc_url($site->site_url); ?>"
                        data-group-id="<?php echo esc_attr($site->group_id); ?>">
                        <?php _e('编辑', 'jefrssfriend'); ?>
                    </button>
                    <button type="button" class="button delete-site" data-id="<?php echo $site->id; ?>">
                        <?php _e('删除', 'jefrssfriend'); ?>
                    </button>
                </td>
            </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
    
    <?php
    // 分页导航
    $page_links = paginate_links(array(
        'base' => add_query_arg('paged', '%#%'),
        'format' => '',
        'prev_text' => __('&laquo;'),
        'next_text' => __('&raquo;'),
        'total' => $total_pages,
        'current' => $current_page,
        'type' => 'list',
        'show_all' => false,
        'end_size' => 1,
        'mid_size' => 2
    ));
    
    if ($page_links) {
        echo '<div class="tablenav"><div class="tablenav-pages">';
        echo '<span class="displaying-num">' . sprintf(
            _n('%s 个项目', '%s 个项目', $total_items),
            number_format_i18n($total_items)
        ) . '</span>';
        echo $page_links;
        echo '</div></div>';
    }
    ?>
    
    <?php else: ?>
    <p><?php _e('暂无RSS源，请添加。', 'jefrssfriend'); ?></p>
    <?php endif; ?>
    
    <script>
        console.log('Page loaded');
        jQuery(document).ready(function($) {
            console.log('jQuery ready');
            $('#debug-info pre').text(
                'AJAX URL: ' + jefrssfriend.ajax_url + '\n' +
                'Nonce: ' + jefrssfriend.nonce
            );
        });
    </script>
</div> 