(function($) {
    'use strict';
    
    // 在文件开头添加通知管理器
    const JefNotification = {
        init: function() {
            // 创建通知容器
            if (!$('#jef-notification-container').length) {
                $('body').append('<div id="jef-notification-container"></div>');
            }
        },

        show: function(message, type = 'info', duration = 3000) {
            // 确保容器存在
            this.init();
            
            const toast = $(`
                <div class="jef-toast ${type}">
                    <div class="toast-content">
                        <span class="message">${message}</span>
                    </div>
                </div>
            `).appendTo('#jef-notification-container');

            // 自动消失
            setTimeout(() => {
                toast.fadeOut(() => toast.remove());
            }, duration);
        }
    };

    $(document).ready(function() {
        console.log('DOM Ready');
        
        // 检查是否在站点管理页面
        if ($('#add-site-form').length) {
            console.log('Found add site form');
            SiteManager.init();
        }
        
        // 阅读中心功能
        if ($('.reader-center').length) {
            initReaderCenter();
        }

        // 分组管理初始化
        if ($('.wp-list-table').length && window.location.href.indexOf('jefrssfriend-groups') > -1) {
            GroupManager.init();
        }

        // 辅助函数：更新URL参数
        function updateQueryStringParameter(uri, key, value) {
            var re = new RegExp("([?&])" + key + "=.*?(&|$)", "i");
            var separator = uri.indexOf('?') !== -1 ? "&" : "?";
            if (uri.match(re)) {
                return uri.replace(re, '$1' + key + "=" + value + '$2');
            } else {
                return uri + separator + key + "=" + value;
            }
        }

        // 前进/后退按钮支持
        window.addEventListener('popstate', function(event) {
            var params = new URLSearchParams(window.location.search);
            var articleId = params.get('id');
            if (articleId) {
                $('.article-item[data-id="' + articleId + '"]').click();
            }
        });
    });

    // 阅读中心初始化
    function initReaderCenter() {
        console.log('初始化阅读中心');
        
        // 添加文章状态管理器
        const ArticleStateManager = {
            updateSelection: function(articleId) {
                $('.article-item').removeClass('active');
                $(`.article-item[data-id="${articleId}"]`).addClass('active');
                console.log('更新选区状态:', articleId);
            }
        };

        // 修改文章点击事件处理
        $('.article-item').on('click', function(e) {
            e.preventDefault();
            const $item = $(this);
            const articleId = $item.data('id');
            const currentFontSize = FontSizeManager.get();
            
            // 立即更新选区状态
            ArticleStateManager.updateSelection(articleId);
            
            $.ajax({
                url: ajaxurl,
                type: 'POST',
                data: {
                    action: 'jefrssfriend_get_article',
                    id: articleId,
                    _wpnonce: jefrssfriend.nonce
                },
                success: function(response) {
                    if (response.success) {
                        $('.reader-content').html(response.data.content);
                        
                        // 重新初始化所有管理器
                        FontSizeManager.bindEvents();
                        FontSizeManager.apply(FontSizeManager.get());
                        DarkModeManager.bindEvents();
                        DarkModeManager.apply(DarkModeManager.get());
                        
                        // 更新URL
                        var newUrl = updateQueryStringParameter(window.location.href, 'id', articleId);
                        history.pushState({articleId: articleId}, '', newUrl);
                    }
                }
            });
        });

        // 修改 popstate 事件处理
        window.removeEventListener('popstate', window.popstateHandler); // 移除可能存在的旧处理器
        window.popstateHandler = function(event) {
            const params = new URLSearchParams(window.location.search);
            const articleId = params.get('id');
            if (articleId) {
                // 先更新选区状态
                ArticleStateManager.updateSelection(articleId);
                // 触发文章加载，但不触发选区更新
                $.ajax({
                    url: ajaxurl,
                    type: 'POST',
                    data: {
                        action: 'jefrssfriend_get_article',
                        id: articleId,
                        _wpnonce: jefrssfriend.nonce
                    },
                    success: function(response) {
                        if (response.success) {
                            $('.reader-content').html(response.data.content);
                            
                            // 重新初始化所有管理器
                            FontSizeManager.bindEvents();
                            FontSizeManager.apply(FontSizeManager.get());
                            DarkModeManager.bindEvents();
                            DarkModeManager.apply(DarkModeManager.get());
                        }
                    }
                });
            }
        };
        window.addEventListener('popstate', window.popstateHandler);

        // 初始化时同步选区状态
        const params = new URLSearchParams(window.location.search);
        const initialArticleId = params.get('id');
        if (initialArticleId) {
            ArticleStateManager.updateSelection(initialArticleId);
        }

        // 统一的字体大小管理
        const FontSizeManager = {
            get: function() {
                return localStorage.getItem('jefrss_font_size') || 'medium';
            },
            save: function(size) {
                localStorage.setItem('jefrss_font_size', size);
                console.log('保存字体大小:', size);
            },
            apply: function(size) {
                const $content = $('.jef-article-content');
                if ($content.length) {
                    // 移除所有尺寸类
                    $content.removeClass('jef-size-small jef-size-medium jef-size-large')
                           .addClass('jef-size-' + size);
                    
                    // 更新按钮状态
                    $('.jef-size-btn').removeClass('active');
                    $(`.jef-size-btn[data-size="${size}"]`).addClass('active');
                }
                console.log('应用字体大小:', size);
            },
            bindEvents: function() {
                console.log('绑定字体大小事件');
                $('.jef-font-control .jef-size-btn').off('click').on('click', function() {
                    const size = $(this).data('size');
                    FontSizeManager.save(size);
                    FontSizeManager.apply(size);
                });
            }
        };

        // 统一的深色模式管理
        const DarkModeManager = {
            get: function() {
                return localStorage.getItem('jefrss_dark_mode') === 'true';
            },
            save: function(isDark) {
                localStorage.setItem('jefrss_dark_mode', isDark);
                console.log('保存夜间模式:', isDark);
            },
            apply: function(isDark) {
                // 强制移除所有可能的状态类
                $('body').removeClass('light-mode dark-mode system-dark-mode');
                
                // 添加明确的模式类
                if (isDark) {
                    $('body').addClass('dark-mode');
                    // 添加 meta 标签来禁用系统的自动夜间模式
                    this.updateColorScheme('dark');
                } else {
                    $('body').addClass('light-mode');
                    this.updateColorScheme('light');
                }
                
                // 强制重新应用样式
                $('.reader-content').hide().show(0);
                console.log('应用夜间模式:', isDark);
            },
            updateColorScheme: function(scheme) {
                // 更新或创建 meta 标签
                let meta = document.querySelector('meta[name="color-scheme"]');
                if (!meta) {
                    meta = document.createElement('meta');
                    meta.name = 'color-scheme';
                    document.head.appendChild(meta);
                }
                meta.content = scheme;
            },
            bindEvents: function() {
                console.log('绑定夜间模式事件');
                
                // 移动端设置按钮点击事件
                $('.mobile-settings-toggle').off('click').on('click', function(e) {
                    e.preventDefault();
                    e.stopPropagation();
                    $('.mobile-settings-menu').toggleClass('active');
                });
                
                // 点击其他区域关闭菜单
                $(document).on('click', function(e) {
                    if (!$(e.target).closest('.mobile-settings-menu, .mobile-settings-toggle').length) {
                        $('.mobile-settings-menu').removeClass('active');
                    }
                });
                
                // 夜间模式切换事件
                $('.toggle-dark-mode').off('click').on('click', function(e) {
                    e.preventDefault();
                    e.stopPropagation();
                    const currentMode = DarkModeManager.get();
                    DarkModeManager.save(!currentMode);
                    DarkModeManager.apply(!currentMode);
                    // 移动端点击后关闭菜单
                    $('.mobile-settings-menu').removeClass('active');
                });
            },
            init: function() {
                // 禁用系统自动夜间模式
                this.updateColorScheme('light');
                
                // 应用保存的设置
                const savedMode = this.get();
                if (savedMode !== null) {
                    this.apply(savedMode);
                } else {
                    // 默认使用浅色模式
                    this.apply(false);
                    this.save(false);
                }
                
                // 绑定事件
                this.bindEvents();
            }
        };

        // 初始化所有功能
        FontSizeManager.bindEvents();
        FontSizeManager.apply(FontSizeManager.get());
        DarkModeManager.init();

        // 返回顶部按钮
        const backToTop = document.querySelector('.back-to-top');
        const readerContent = document.querySelector('.reader-content');

        if (backToTop && readerContent) {
            console.log('Found back-to-top button and reader content');
            
            // 监听阅读区域的滚动事件
            readerContent.addEventListener('scroll', () => {
                const shouldShow = readerContent.scrollTop > 100;
                console.log('Reader scroll position:', readerContent.scrollTop, 'Should show:', shouldShow);
                
                // 使用 requestAnimationFrame 优化性能
                requestAnimationFrame(() => {
                    if (shouldShow) {
                        backToTop.classList.add('visible');
                    } else {
                        backToTop.classList.remove('visible');
                    }
                });
            });

            // 点击事件
            backToTop.addEventListener('click', (e) => {
                e.preventDefault();
                console.log('Back to top clicked');
                
                // 平滑滚动到阅读区域顶部
                readerContent.scrollTo({
                    top: 0,
                    behavior: 'smooth'
                });
            });
        } else {
            console.warn('Back to top button or reader content not found in DOM');
        }
    }

    // 站点管理
    var SiteManager = {
        init: function() {
            console.log('初始化站点管理');
            this.bindEvents();
            this.initFormValidation();
            this.initPopup();
        },
        
        initPopup: function() {
            // 点击添加按钮显示弹窗
            $('.add-site-btn').on('click', function() {
                console.log('点击添加按钮');
                $('#site-form').show();
                $('#form-overlay').show();
                // 清空表单
                $('#site-form form')[0].reset();
                $('#site-id').val('');
            });
            
            // 关闭弹窗
            $('.close-form, #form-overlay').on('click', function() {
                console.log('点击关闭按钮');
                $('#site-form, #form-overlay').hide();
            });
            
            // 阻止点击弹窗内容时关闭
            $('#site-form').on('click', function(e) {
                e.stopPropagation();
            });
        },
        
        bindEvents: function() {
            $('#site-form form').on('submit', function(e) {
                e.preventDefault();
                console.log('表单提交');
                
                var formData = {
                    action: 'jefrssfriend_add_site',
                    _ajax_nonce: jefrssfriend.nonce,
                    title: $('#site-title').val(),
                    rss_url: $('#rss-url').val(),
                    site_url: $('#site-url').val(),
                    site_id: $('#site-id').val(),
                    icon_url: $('#icon-url').val(),
                    group_id: $('#group-id').val()
                };
                
                console.log('发送的数据:', formData);
                
                var $submitBtn = $(this).find('button[type="submit"]');
                $submitBtn.prop('disabled', true).text('保存中...');
                
                $.ajax({
                    url: ajaxurl,
                    type: 'POST',
                    data: formData,
                    success: function(response) {
                        if (response.success) {
                            // 使用新的通知系统
                            JefNotification.show(response.data.message, 'success');
                        } else {
                            JefNotification.show(response.data.message || '操作失败', 'error');
                        }
                    },
                    error: function(xhr, status, error) {
                        // 使用新的通知系统
                        JefNotification.show('请求失败，请重试', 'error');
                    },
                    complete: function() {
                        $submitBtn.prop('disabled', false).text('保存');
                    }
                });
            });
            
            // 编辑站点
            $('.edit-site').on('click', function() {
                console.log('点击编辑按钮');
                var $btn = $(this);
                var data = $btn.data();
                
                // 填充表单数据
                $('#site-id').val(data.id);
                $('#site-title').val(data.title);
                $('#rss-url').val(data.rssUrl);
                $('#site-url').val(data.siteUrl);
                $('#group-id').val(data.groupId || '0');
                
                // 显示弹窗
                $('#site-form, #form-overlay').show();
            });

            // 刷新单个站点
            $('.refresh-site').on('click', function() {
                const $btn = $(this);
                const siteId = $btn.data('id');
                const $row = $btn.closest('tr');
                const siteName = $row.find('td:eq(1)').text().trim();
                
                // 添加加载状态
                $btn.prop('disabled', true).text('刷新中...');
                
                $.ajax({
                    url: ajaxurl,
                    type: 'POST',
                    data: {
                        action: 'jefrssfriend_refresh_single_site',
                        id: siteId,
                        _ajax_nonce: jefrssfriend.nonce
                    },
                    success: function(response) {
                        if (response.success) {
                            // 更新按钮状态
                            $btn.prop('disabled', false).text('刷新');
                            
                            // 更新最后刷新时间
                            $row.find('.last-fetch').text(response.data.last_fetch);
                            
                            // 更新文章数量
                            if (response.data.articles_count !== undefined) {
                                $row.find('.articles-count').text(response.data.articles_count);
                            }
                            
                            // 显示成功消息
                            alert('刷新成功！获取了 ' + response.data.articles_count + ' 篇文章');
                            
                            // 如果在阅读页面，可能需要刷新文章列表
                            if ($('.reader-center').length) {
                                location.reload();
                            }
                        } else {
                            $btn.prop('disabled', false).text('刷新');
                            alert('刷新失败: ' + (response.data.message || '未知错误'));
                        }
                    },
                    error: function(xhr, status, error) {
                        console.error('刷新请求失败:', {xhr: xhr, status: status, error: error});
                        $btn.prop('disabled', false).text('刷新');
                        alert('请求失败，请重试');
                    },
                    complete: function() {
                        // 确保按钮一定会被重置
                        if ($btn.prop('disabled')) {
                            $btn.prop('disabled', false).text('刷新');
                        }
                    }
                });
            });
        },
        
        initFormValidation: function() {
            $('#add-site-form').on('submit', function(e) {
                var $form = $(this);
                var title = $('#site-title').val().trim();
                var rssUrl = $('#rss-url').val().trim();
                
                if (!title) {
                    alert('请输入站点名称');
                    return false;
                }
                
                if (!rssUrl) {
                    alert('请输入RSS地址');
                    return false;
                }
                
                if (!rssUrl.match(/^https?:\/\/.+/i)) {
                    alert('请输入有效的RSS地址');
                    return false;
                }
            });
        }
    };
    
    // 分组管理
    var GroupManager = {
        init: function() {
            console.log('初始化分组管理');
            this.bindEvents();
        },
        
        bindEvents: function() {
            // 添加分组按钮点击事件
            $('.add-group-btn').on('click', function() {
                console.log('点击添加分组按钮');
                // 重置表单
                $('#group-form form')[0].reset();
                $('#group-id').val('');
                // 显示表单
                $('#group-form, #group-form-overlay').show();
            });
            
            // 编辑分组按钮点击事件
            $('.edit-group').on('click', function() {
                console.log('点击编辑分组按钮');
                const $btn = $(this);
                const groupId = $btn.data('id');
                const groupName = $btn.data('name');
                const groupOrder = $btn.data('order');
                
                console.log('编辑分组数据:', {
                    id: groupId,
                    name: groupName,
                    order: groupOrder
                });
                
                // 填充表单
                $('#group-id').val(groupId);
                $('#group-name').val(groupName);
                $('#group-order').val(groupOrder);
                
                // 显示表单
                $('#group-form, #group-form-overlay').show();
            });
            
            // 表单提交事件
            $('#group-form form').on('submit', function(e) {
                e.preventDefault();
                console.log('提交分组表单');
                
                const $form = $(this);
                const $submitBtn = $form.find('button[type="submit"]');
                
                // 获取表单数据
                const formData = {
                    action: 'jefrssfriend_add_group',
                    _ajax_nonce: jefrssfriend.nonce,
                    group_id: $('#group-id').val(),
                    name: $('#group-name').val(),
                    order_num: $('#group-order').val()
                };
                
                console.log('发送的数据:', formData);
                
                // 禁用提交按钮
                $submitBtn.prop('disabled', true).text('保存中...');
                
                $.ajax({
                    url: ajaxurl,
                    type: 'POST',
                    data: formData,
                    success: function(response) {
                        console.log('服务器响应:', response);
                        if (response.success) {
                            location.reload();
                        } else {
                            alert(response.data || '保存失败');
                            $submitBtn.prop('disabled', false).text('保存');
                        }
                    },
                    error: function(xhr, status, error) {
                        console.error('AJAX错误:', {xhr: xhr, status: status, error: error});
                        alert('请求失败，请重试');
                        $submitBtn.prop('disabled', false).text('保存');
                    }
                });
            });
            
            // 关闭表单
            $('.cancel-btn, #group-form-overlay').on('click', function() {
                $('#group-form, #group-form-overlay').hide();
            });
            
            // 阻止表单点击事件冒泡
            $('#group-form').on('click', function(e) {
                e.stopPropagation();
            });

            // 添加删除分组按钮点击事件
            $('.delete-group').on('click', function() {
                console.log('点击删除分组按钮');
                const $btn = $(this);
                const groupId = $btn.data('id');
                
                // 确认删除
                if (!confirm('确定要删除这个分组吗？')) {
                    return;
                }
                
                console.log('删除分组:', groupId);
                
                $.ajax({
                    url: ajaxurl,
                    type: 'POST',
                    data: {
                        action: 'jefrssfriend_delete_group',
                        id: groupId,
                        _ajax_nonce: jefrssfriend.nonce
                    },
                    success: function(response) {
                        console.log('服务器响应:', response);
                        if (response.success) {
                            location.reload();
                        } else {
                            alert(response.data || '删除失败');
                        }
                    },
                    error: function(xhr, status, error) {
                        console.error('AJAX错误:', {xhr: xhr, status: status, error: error});
                        alert('请求失败，请重试');
                    }
                });
            });
        }
    };
    
    $(document).ready(function() {
        // 将函数定义移到外部
        var showForm = function() {
            $('#form-overlay').fadeIn();
            $('#site-form').fadeIn();
            $('body').css('overflow', 'hidden');
        };
        
        var hideForm = function() {
            $('#form-overlay').fadeOut();
            $('#site-form').fadeOut();
            $('body').css('overflow', 'auto');
        };
        
        var resetForm = function() {
            $('#site-id').val('');
            $('#site-title').val('');
            $('#rss-url').val('');
            $('#site-url').val('');
            $('#icon-url').val('');
            $('#group-id').val(0);
        };
        
        var fillForm = function(data) {
            $('input[name="site_id"]').val(data.id);
            $('#site-title').val(data.title);
            $('#rss-url').val(data.rss_url);
            $('#site-url').val(data.site_url);
            $('#icon-url').val(data.icon_url);
            $('#group-id').val(data.group_id ? data.group_id : '0');
            
            // 调试输出
            console.log('Filling form with data:', data);
            console.log('Group ID set to:', data.group_id);
        };
        
        // 点击添加新站点按钮
        $('#add-new-site').on('click', function() {
            resetForm();
            showForm();
        });
        
        // 点击关闭按钮或遮罩层关闭表单
        $(document).on('click', '.close-form, #form-overlay', function() {
            hideForm();
        });
        
        // 阻止表单内点击事件冒泡到遮罩层
        $(document).on('click', '#site-form', function(e) {
            e.stopPropagation();
        });
        
        // 点击编辑按钮
        $(document).on('click', '.edit-site', function(e) {
            e.preventDefault();
            var $btn = $(this);
            var siteData = {
                id: $btn.data('id'),
                title: $btn.data('title'),
                rss_url: $btn.data('rss-url'),
                site_url: $btn.data('site-url'),
                icon_url: $btn.data('icon-url'),
                group_id: $btn.data('group-id')
            };
            
            // 调试输出
            console.log('Editing site:', siteData);
            
            fillForm(siteData);
            showForm();
        });
        
        // 删除站点按钮 - 使用事件委托
        $(document).on('click', '.delete-site', function(e) {
            e.preventDefault();
            var id = $(this).data('id');
            console.log('Delete button clicked via delegation, id:', id);
            if (confirm('确定要删除这个RSS源吗？')) {
                $.ajax({
                    url: jefrssfriend.ajax_url,
                    type: 'POST',
                    data: {
                        action: 'jefrssfriend_delete_site',
                        id: id,
                        _ajax_nonce: jefrssfriend.nonce
                    },
                    success: function(response) {
                        console.log('Delete response:', response);
                        if (response.success) {
                            alert('删除成功！');
                            location.reload();
                        } else {
                            alert(response.data);
                        }
                    },
                    error: function(xhr, status, error) {
                        console.log('Delete error:', {xhr, status, error});
                        alert('删除失败，请重试');
                    }
                });
            }
        });
        
        // OPML导入处理
        $('#opml-import-form').on('submit', function(e) {
            e.preventDefault();
            
            var $form = $(this);
            var $button = $('#import-opml-button');
            var $result = $('#import-result');
            var $debug = $('#debug-output pre');
            
            // 显示调试信息
            $debug.show().text('正在准备上传...\n');
            
            var formData = new FormData(this);
            formData.append('action', 'jefrssfriend_import_opml');
            formData.append('_wpnonce', jefrssfriend.nonce);
            
            $debug.append('FormData 内容:\n' + 
                Array.from(formData.entries())
                    .map(e => e[0] + ': ' + (e[1] instanceof File ? e[1].name : e[1]))
                    .join('\n')
            );
            
            $button.prop('disabled', true).text('导入中...');
            
            $.ajax({
                url: jefrssfriend.ajax_url,
                type: 'POST',
                data: formData,
                processData: false,
                contentType: false,
                beforeSend: function(xhr) {
                    $debug.append('\n\n发送请求...');
                    xhr.setRequestHeader('X-Requested-With', 'XMLHttpRequest');
                },
                success: function(response) {
                    $debug.append('\n\n服务器响应:\n' + JSON.stringify(response, null, 2));
                    if (response.success) {
                        $result.html('<div class="notice notice-success"><p>' + response.data.message + '</p></div>').show();
                        $form[0].reset();
                    } else {
                        $result.html('<div class="notice notice-error"><p>' + response.data + '</p></div>').show();
                    }
                },
                error: function(xhr, status, error) {
                    $debug.append('\n\n请求失败:\n' + 
                        'Status: ' + status + '\n' +
                        'Error: ' + error + '\n' +
                        'Response: ' + xhr.responseText
                    );
                    $result.html('<div class="notice notice-error"><p>导入失败，请重试</p></div>').show();
                },
                complete: function() {
                    $button.prop('disabled', false).text('开始导入');
                }
            });
        });
        
        // 刷新全部订阅源
        $('#refresh-all-feeds').on('click', function() {
            var $button = $(this);
            var $progress = $('.refresh-progress');
            var $progressBar = $progress.find('.progress-bar');
            var $progressText = $progress.find('.progress-text');
            var $errors = $('.refresh-errors');
            
            // 如果按钮已禁用,直接返回
            if ($button.prop('disabled')) {
                return;
            }
            
            // 1. 显示和重置进度条
            $progress.fadeIn();
            $progressBar.css('width', '0%');
            $progressText.html('准备开始刷新...');
            $errors.hide().empty();
            
            // 2. 禁用按钮并显示加载状态
            $button.prop('disabled', true);
            
            // 3. 开始刷新操作
            refreshFeeds(0);
        });
        
        // 分批刷新函数
        function refreshFeeds(offset, retryCount = 0) {
            const $button = $('#refresh-all-feeds');
            const $progress = $('.refresh-progress');
            const $progressBar = $progress.find('.progress-bar');
            const $progressText = $progress.find('.progress-text');
            const $errors = $('.refresh-errors');
            
            // 添加暂停按钮
            if (!$('#pause-refresh').length) {
                $button.after('<button id="pause-refresh" class="button">暂停</button>');
            }
            
            // 暂停功能
            let isPaused = false;
            $('#pause-refresh').on('click', function() {
                isPaused = !isPaused;
                $(this).text(isPaused ? '继续' : '暂停');
            });
            
            // 如果暂停了，等待继续
            if (isPaused) {
                setTimeout(() => refreshFeeds(offset), 1000);
                return;
            }

            $.ajax({
                url: ajaxurl,
                type: 'POST',
                data: {
                    action: 'jefrssfriend_refresh_feeds',
                    offset: offset,
                    _wpnonce: $('#_wpnonce').val()
                },
                success: function(response) {
                    console.log('AJAX响应:', response);
                    
                    if (response.success) {
                        // 更新进度条
                        $progressBar.css('width', response.data.progress + '%');
                        
                        // 更新状态文本
                        $progressText.html(
                            '处理站点进度: ' + response.data.processed + '/' + response.data.total + 
                            ' (' + response.data.progress + '%)<br>' +
                            '已获取文章: ' + response.data.articles + ' 篇'
                        );
                        
                        // 继续处理或完成
                        if (response.data.processed < response.data.total) {
                            setTimeout(() => refreshFeeds(response.data.processed), 1000);
                        } else {
                            // 完成刷新
                            $progressText.html(`
                                <span class="success">
                                    ✓ 刷新完成! 共处理 ${response.data.processed} 个源，
                                    获取 ${response.data.articles} 篇新文章
                                </span>
                            `);
                            
                            // 延迟3秒后刷新页面
                            setTimeout(() => location.reload(), 3000);
                        }
                    } else {
                        handleError(response.data?.message || '未知错误', offset, retryCount);
                    }
                },
                error: function(xhr, status, error) {
                    console.error('AJAX Error:', {xhr, status, error});
                    handleError(`请求失败: ${status}`, offset, retryCount);
                }
            });
        }
        
        // 错误处理函数
        function handleError(message, offset, retryCount) {
            const $button = $('#refresh-all-feeds');
            const $progressText = $('.progress-text');
            const $errors = $('.refresh-errors');
            
            // 如果重试次数小于3,则重试
            if (retryCount < 3) {
                $progressText.html(`<span class="error">× 刷新失败,正在重试(${retryCount + 1}/3)...</span>`);
                setTimeout(() => refreshFeeds(offset, retryCount + 1), 2000);
            } else {
                // 显示错误信息
                $progressText.html(`<span class="error">× 刷新失败</span>`);
                $errors.html(`
                    <div class="error-list">
                        <h4>错误信息:</h4>
                        <p>${message}</p>
                    </div>
                `).fadeIn();
                
                // 恢复按钮状态
                $button.prop('disabled', false);
            }
        }
        
        // 处理清理文章表单提交
        $('#cleanup-form').on('submit', function(e) {
            e.preventDefault();
            
            var $form = $(this);
            var $button = $form.find('button');
            
            $button.prop('disabled', true)
                   .text('正在清理...');
            
            $.ajax({
                url: ajaxurl,
                type: 'POST',
                data: {
                    action: 'jefrssfriend_cleanup_articles',
                    _wpnonce: $form.find('#_wpnonce').val()
                },
                success: function(response) {
                    if (response.success) {
                        // 使用 WordPress 内置的通知系统
                        showAdminNotice('success', '成功清理了 ' + response.data.cleaned + ' 篇旧文章');
                    } else {
                        showAdminNotice('error', '清理失败: ' + response.data.message);
                    }
                },
                error: function() {
                    showAdminNotice('error', '清理过程出错，请重试');
                },
                complete: function() {
                    $button.prop('disabled', false)
                           .text('清理旧文章');
                }
            });
        });
        
        // 恢复通知函数
        function showAdminNotice(type, message) {
            JefNotification.show(message, type);
        }
        
        // 添加错误处理
        window.onerror = function(msg, url, lineNo, columnNo, error) {
            console.error('JavaScript错误:', {
                message: msg,
                url: url,
                lineNo: lineNo,
                columnNo: columnNo,
                error: error
            });
            return false;
        };
        
        // 添加AJAX错误全局处理
        $(document).ajaxError(function(event, jqXHR, settings, error) {
            console.error('AJAX请求失败:', {
                event: event,
                jqXHR: jqXHR,
                settings: settings,
                error: error
            });
        });
    });
    
    // 图片加载处理
    document.addEventListener('DOMContentLoaded', function() {
        const images = document.querySelectorAll('.article-image img');
        const TIMEOUT = 10000; // 10秒超时

        images.forEach(img => {
            const timer = setTimeout(() => {
                if (!img.complete) {
                    // 图片加载超时
                    img.parentElement.style.display = 'none';
                    img.closest('.article-layout').classList.add('no-image');
                }
            }, TIMEOUT);

            img.onload = () => {
                clearTimeout(timer);
            };

            img.onerror = () => {
                clearTimeout(timer);
                img.parentElement.style.display = 'none';
                img.closest('.article-layout').classList.add('no-image');
            };
        });
    });
    
    // 处理 AJAX 表单提交
    $('.ajax-form').on('submit', function(e) {
        e.preventDefault();
        
        const $form = $(this);
        const $button = $form.find('button[type="submit"]');
        
        // 确认提示
        if ($button.data('confirm') && !confirm($button.data('confirm'))) {
            return;
        }
        
        // 禁用按钮
        $button.prop('disabled', true);
        
        $.ajax({
            url: ajaxurl,
            type: 'POST',
            data: $form.serialize(),
            success: function(response) {
                if (response.success) {
                    JefNotification.show(response.data.message, response.data.type);
                    if (response.data.reload) {
                        setTimeout(() => location.reload(), 1000);
                    }
                } else {
                    JefNotification.show(response.data.message, 'error');
                }
            },
            error: function() {
                JefNotification.show('请求失败，请重试', 'error');
            },
            complete: function() {
                $button.prop('disabled', false);
            }
        });
    });
})(jQuery); 

 // 