(function($) {
    'use strict';
    
    // 文章点击处理
    function initArticleHandlers() {
        $('.list-content').on('click', '.article-item', function(e) {
            e.preventDefault();
            e.stopPropagation();
            
            const $item = $(this);
            const $content = $item.next('.mobile-article-content');
            
            // 如果正在加载中，忽略点击
            if ($item.hasClass('loading')) {
                return;
            }
            
            // 切换展开状态
            if ($item.hasClass('expanded')) {
                // 收起
                $item.removeClass('expanded');
                $content.slideUp(200, function() {
                    $(this).removeClass('visible');
                });
            } else {
                // 展开前先收起其他已展开的文章
                $('.article-item.expanded').each(function() {
                    const $expandedItem = $(this);
                    const $expandedContent = $expandedItem.next('.mobile-article-content');
                    $expandedItem.removeClass('expanded');
                    $expandedContent.slideUp(200).removeClass('visible');
                });
                
                // 移除所有文章的选区
                $('.article-item').removeClass('expanded');
                // 给当前文章添加选区
                $item.addClass('expanded');
                
                $item.addClass('loading');
                
                // 如果内容为空才加载
                if (!$content.html().trim()) {
                    $.ajax({
                        url: ajaxurl,
                        type: 'POST',
                        data: {
                            action: 'jefrssfriend_get_article',
                            id: $item.data('id'),
                            is_mobile: 'true',
                            _wpnonce: jefrssfriend.nonce
                        }
                    })
                    .then(response => {
                        if (!response.success) {
                            throw new Error(response.data);
                        }
                        $content.html(response.data.content);
                        showContent();
                    })
                    .catch(error => {
                        ErrorHandler.show(error.message);
                        $item.removeClass('loading');
                    });
                } else {
                    showContent();
                }

                function showContent() {
                    $content
                        .addClass('visible')
                        .slideDown(200, function() {
                            const headerHeight = $('.list-header').outerHeight() || 0;
                            const scrollTop = $item.offset().top - headerHeight - 15;
                            
                            $('html, body').animate({
                                scrollTop: scrollTop
                            }, {
                                duration: 300,
                                easing: 'swing',
                                complete: function() {
                                    // 滚动完成后更新选区
                                    $('.article-item').removeClass('active');
                                    $item.addClass('active');
                                }
                            });
                        });
                    $item.removeClass('loading');
                }
            }
        });
    }

    // 关闭文章
    function closeArticle($item, $content) {
        console.log('Closing article:', $item.data('id')); // 添加调试日志
        
        $item.removeClass('expanded');
        $content
            .slideUp(300, function() {
                $(this)
                    .removeClass('visible')
                    .css('display', 'none')
                    .empty();
                console.log('Article closed'); // 添加调试日志
            });
    }

    // 打开文章
    function openArticle($item, $content, articleId) {
        console.log('Opening article:', articleId); // 添加调试日志
        
        $item.addClass('expanded loading');
        
        // 直接从服务器加载内容
        $.ajax({
            url: ajaxurl,
            type: 'POST',
            data: {
                action: 'jefrssfriend_get_article',
                id: articleId,
                is_mobile: 'true',
                _wpnonce: jefrssfriend.nonce
            },
            beforeSend: function() {
                LoadingProgress.start();
            }
        })
        .then(response => {
            if (!response.success) {
                throw new Error(response.data);
            }
            showArticleContent($content, response.data.content);
            LoadingProgress.complete();
        })
        .catch(error => {
            console.error('Error loading article:', error); // 添加调试日志
            ErrorHandler.show(error.message);
            $item.removeClass('expanded');
            LoadingProgress.complete();
        })
        .finally(() => {
            $item.removeClass('loading');
        });
    }

    // 显示文章内容
    function showArticleContent($content, content) {
        $content
            .html(content)
            .addClass('visible')
            .hide()
            .slideDown(300);
        
        // 滚动到文章位置
        $('html, body').animate({
            scrollTop: $content.offset().top - 60
        }, 300);
        
        // 初始化文章内容中的交互元素
        initArticleContentInteractions($content);
    }

    // 初始化文章内容中的交互元素
    function initArticleContentInteractions($content) {
        // 图片点击放大等功能
        $content.find('img').on('click', function(e) {
            e.stopPropagation();
            const $img = $(this);
            showImageViewer($img.attr('src'));
        });
        
        // 链接点击
        $content.find('a').on('click', function(e) {
            e.stopPropagation();
        });
    }

    // 图片查看器
    function showImageViewer(src) {
        const $viewer = $('<div class="image-viewer">')
            .append($('<img>').attr('src', src))
            .appendTo('body');
        
        $viewer.on('click', function() {
            $(this).fadeOut(200, function() {
                $(this).remove();
            });
        });
    }

    // 返回顶部按钮
    function initBackToTop() {
        const $backToTop = $('.back-to-top');
        const $mobileView = $('.mobile-view');  // 获取滚动容器
        
        // 监听移动视图的滚动事件
        $mobileView.on('scroll', function() {
            if ($(this).scrollTop() > 100) {
                $backToTop.fadeIn();
            } else {
                $backToTop.fadeOut();
            }
        });
        
        // 点击事件处理
        $backToTop.on('click', function(e) {
            e.preventDefault();
            e.stopPropagation();
            
            // 平滑滚动到顶部
            $mobileView.animate({
                scrollTop: 0
            }, 300);
        });
    }

    // 加载进度条
    const LoadingProgress = {
        $bar: null,
        
        init: function() {
            this.$bar = $('.reading-progress');
        },
        
        start: function() {
            this.$bar.css('width', '0%').show();
        },
        
        set: function(percent) {
            this.$bar.css('width', percent + '%');
        },
        
        complete: function() {
            this.$bar.css('width', '100%').fadeOut(200);
        }
    };

    // 错误处理
    const ErrorHandler = {
        show: function(message) {
            const $error = $('<div class="error-message">')
                .text(message)
                .appendTo('body');
            
            setTimeout(() => {
                $error.fadeOut(200, function() {
                    $(this).remove();
                });
            }, 3000);
        }
    };

    // 初始化夜间模式
    function initDarkMode() {
        const options = {
            bottom: 'unset',  // 禁用默认悬浮按钮
            right: 'unset', 
            left: 'unset',
            time: '0.3s',    // 切换动画时间
            mixColor: '#fff', // 混合色
            backgroundColor: '#fff',  // 背景色
            buttonColorDark: '#1a1a1a',  
            buttonColorLight: '#fff',
            saveInCookies: true,     // 保存到 cookies
            label: '',               // 不使用默认按钮
            autoMatchOsTheme: false  // 禁用自动跟随系统主题
        };

        // 初始化 darkmode
        const darkmode = new Darkmode(options);

        // 绑定自定义切换按钮
        $('.toggle-dark-mode').on('click', function(e) {
            e.preventDefault();
            e.stopPropagation();
            darkmode.toggle();
            
            // 更新theme-color
            const isDark = darkmode.isActivated();
            const themeColor = isDark ? '#242424' : '#ffffff';
            $('meta[name="theme-color"]').attr('content', themeColor);
        });

        // 初始应用保存的主题
        if (darkmode.isActivated()) {
            $('body').addClass('darkmode--activated');
        }
    }

    // 添加滚动监听函数
    function initScrollSpy() {
        const $window = $(window);
        const $articles = $('.article-item');
        const $header = $('.list-header');
        let headerHeight = $header.outerHeight() || 0;
        let ticking = false;

        $window.on('scroll', function() {
            if (!ticking) {
                window.requestAnimationFrame(function() {
                    updateActiveArticle();
                    ticking = false;
                });
                ticking = true;
            }
        });

        function updateActiveArticle() {
            const scrollTop = $window.scrollTop() + headerHeight + 20; // 添加一些偏移量
            let activeArticle = null;

            // 找到当前视口中最顶部的文章
            $articles.each(function() {
                const $article = $(this);
                const articleTop = $article.offset().top;
                const articleBottom = articleTop + $article.outerHeight();

                if (articleTop <= scrollTop && articleBottom > scrollTop) {
                    activeArticle = $article;
                    return false; // 跳出循环
                }
            });

            // 更新选区
            $articles.removeClass('active');
            if (activeArticle) {
                activeArticle.addClass('active');
            }
        }

        // 初始化时执行一次
        updateActiveArticle();

        // 窗口大小改变时重新计算头部高度
        $window.on('resize', function() {
            headerHeight = $header.outerHeight() || 0;
            updateActiveArticle();
        });
    }

    // 在文档加载完成后初始化
    $(document).ready(function() {
        if ($('.mobile-view').length) {
            initArticleHandlers();
            initBackToTop();
            LoadingProgress.init();
            initDarkMode();
            initScrollSpy();
        }
    });
})(jQuery); 