<?php
class JefRSSFriend_Activator {
    
    public static function activate() {
        global $wpdb;
        
        try {
            // 设置字符集
            $charset_collate = $wpdb->get_charset_collate();
            
            // 创建站点表
            $sql_sites = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}jefrss_sites (
                id bigint(20) NOT NULL AUTO_INCREMENT,
                title varchar(255) NOT NULL,
                rss_url varchar(255) NOT NULL,
                site_url varchar(255),
                icon_url varchar(255),
                group_id bigint(20),
                status varchar(20) DEFAULT 'active',
                last_fetch datetime,
                created_at datetime DEFAULT CURRENT_TIMESTAMP,
                updated_at datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                PRIMARY KEY  (id),
                KEY status (status),
                KEY group_id (group_id)
            ) $charset_collate;";
            
            // 创建文章表
            $sql_articles = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}jefrss_articles (
                id bigint(20) NOT NULL AUTO_INCREMENT,
                site_id bigint(20) NOT NULL,
                title text NOT NULL,
                content longtext NOT NULL,
                description text,
                link varchar(255) NOT NULL,
                pub_date datetime NOT NULL,
                article_hash varchar(32) NOT NULL,
                created_at datetime DEFAULT CURRENT_TIMESTAMP,
                PRIMARY KEY  (id),
                KEY site_id (site_id),
                KEY pub_date (pub_date),
                UNIQUE KEY unique_article (site_id, article_hash)
            ) $charset_collate;";
            
            // 创建分组表
            $sql_groups = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}jefrss_groups (
                id bigint(20) NOT NULL AUTO_INCREMENT,
                name varchar(255) NOT NULL,
                description text,
                order_num int(11) DEFAULT 0,
                created_at datetime DEFAULT CURRENT_TIMESTAMP,
                updated_at datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                PRIMARY KEY  (id),
                KEY order_num (order_num)
            ) $charset_collate;";
            
            // 创建日志表
            $sql_logs = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}jefrss_logs (
                id bigint(20) NOT NULL AUTO_INCREMENT,
                type varchar(20) NOT NULL COMMENT '日志类型:cron/manual',
                action varchar(50) NOT NULL COMMENT '操作类型:fetch/refresh/error',
                site_id bigint(20) DEFAULT NULL,
                site_url varchar(255) DEFAULT NULL,
                status varchar(20) NOT NULL DEFAULT 'success',
                message text DEFAULT NULL,
                created_at datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
                PRIMARY KEY (id),
                KEY idx_type_created (type, created_at)
            ) $charset_collate;";
            
            require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
            
            // 分别执行每个表的创建
            $result_sites = dbDelta($sql_sites);
            $result_articles = dbDelta($sql_articles);
            $result_groups = dbDelta($sql_groups);
            $result_logs = dbDelta($sql_logs);
            
            // 验证表是否创建成功
            $tables = array(
                $wpdb->prefix . 'jefrss_sites',
                $wpdb->prefix . 'jefrss_articles',
                $wpdb->prefix . 'jefrss_groups',
                $wpdb->prefix . 'jefrss_logs'
            );
            
            foreach ($tables as $table) {
                if ($wpdb->get_var("SHOW TABLES LIKE '$table'") != $table) {
                    throw new Exception("Failed to create table: $table");
                }
            }
            
            // 设置版本号
            update_option('jefrssfriend_db_version', '1.0.0');
            
            error_log('JefRSS: Tables created successfully');
            
        } catch (Exception $e) {
            error_log('JefRSS activation error: ' . $e->getMessage());
            throw $e;
        }
    }
    
    /**
     * 添加文章唯一索引
     */
    private static function add_unique_article_index() {
        global $wpdb;
        
        // 检查索引是否存在
        $index_exists = $wpdb->get_results("SHOW INDEX FROM {$wpdb->prefix}jefrss_articles WHERE Key_name = 'unique_article'");
        
        if (empty($index_exists)) {
            try {
                // 添加唯一索引
                $wpdb->query("ALTER TABLE {$wpdb->prefix}jefrss_articles 
                             ADD UNIQUE INDEX unique_article (site_id, article_hash)");
                
                error_log('成功添加文章唯一索引');
            } catch (Exception $e) {
                error_log('添加文章唯一索引失败: ' . $e->getMessage());
            }
        }
    }
    
    /**
     * 升级数据库
     */
    public static function upgrade() {
        $current_version = get_option('jefrssfriend_db_version', '0');
        
        if (version_compare($current_version, '1.0.0', '<')) {
            self::add_unique_article_index();
            update_option('jefrssfriend_db_version', '1.0.0');
        }
    }
} 