<?php
if (!defined('ABSPATH')) exit;

class JefRSSFriend_Lite_Public {
    private $options;
    
    public function __construct() {
        $this->options = get_option('jefrssfriend_options', array());
        
        // 注册和加载前端样式
        add_action('wp_enqueue_scripts', array($this, 'enqueue_styles'));
        
        // 注册短代码
        add_shortcode('jefrss_latest', array($this, 'shortcode_latest'));
        add_shortcode('jefrss_group', array($this, 'shortcode_group'));
        add_shortcode('jefrss_site', array($this, 'shortcode_site'));
        add_shortcode('jefrss_reader', array($this, 'shortcode_reader'));
    }
    
    /**
     * 最新文章短代码
     */
    public function shortcode_latest($atts) {
        // 获取默认值
        $defaults = array(
            'count' => isset($this->options['latest_count']) ? intval($this->options['latest_count']) : 10,
            'excerpt_length' => isset($this->options['excerpt_length']) ? intval($this->options['excerpt_length']) : 150
        );
        
        // 处理传入的参数
        $atts = shortcode_atts($defaults, $atts, 'jefrss_latest');
        
        // 确保参数为正确的类型
        $atts['count'] = intval($atts['count']);
        $atts['excerpt_length'] = intval($atts['excerpt_length']);
        
        // 调试输出
        error_log('Shortcode atts: ' . print_r($atts, true));
        
        $json_file = JEFRSSFRIEND_PATH . 'data/latest.json';
        if (!file_exists($json_file)) {
            return '<p>' . __('暂无文章', 'jefrssfriend') . '</p>';
        }
        
        $articles = json_decode(file_get_contents($json_file));
        $articles = array_slice($articles, 0, $atts['count']);
        
        // 调试输出
        error_log('Shortcode atts: ' . print_r($atts, true));
        error_log('Articles count: ' . count($articles));
        
        ob_start();
        include JEFRSSFRIEND_PATH . 'public/views/latest-articles.php';
        return ob_get_clean();
    }
    
    /**
     * 分组文章短代码
     */
    public function shortcode_group($atts) {
        $atts = shortcode_atts(array(
            'id' => 0,
            'name' => '',
            'count' => 10,
            'show_images' => isset($this->options['show_images']) ? $this->options['show_images'] : true
        ), $atts, 'jefrss_group');
        
        global $wpdb;
        
        // 构建查询条件
        $where = '';
        if ($atts['id']) {
            $where = $wpdb->prepare("WHERE s.group_id = %d", $atts['id']);
        } elseif ($atts['name']) {
            $where = $wpdb->prepare("WHERE g.name = %s", $atts['name']);
        }
        
        // 获取分组文章
        $articles = $wpdb->get_results($wpdb->prepare("
            SELECT a.*, s.title as site_title, s.icon_url 
            FROM {$wpdb->prefix}jefrss_articles a
            LEFT JOIN {$wpdb->prefix}jefrss_sites s ON a.site_id = s.id
            LEFT JOIN {$wpdb->prefix}jefrss_groups g ON s.group_id = g.id
            {$where}
            ORDER BY a.pub_date DESC
            LIMIT %d
        ", $atts['count']));
        
        ob_start();
        include JEFRSSFRIEND_PATH . 'public/views/group-articles.php';
        return ob_get_clean();
    }
    
    /**
     * 注册和加载前端样式
     */
    public function enqueue_styles() {
        wp_enqueue_style(
            'jefrssfriend-public',
            JEFRSSFRIEND_URL . 'assets/css/public.css',
            array(),
            JEFRSSFRIEND_VERSION
        );
    }
} 