<?php
if (!defined('ABSPATH')) exit;

class JefRSSFriend_Lite_Settings {
    private $options;
    private $settings_fields;
    
    public function __construct() {
        $this->options = get_option('jefrssfriend_options', array());
        add_action('admin_init', array($this, 'register_settings'));
        add_action('admin_init', array($this, 'handle_maintenance_requests'));
    }
    
    private function init_settings_fields() {
        // 基本设置
        $this->settings_fields['basic'] = array(
            'title' => __('基本设置', 'jefrssfriend'),
            'fields' => array(
                'articles_per_feed' => array(
                    'title' => __('每次更新获取文章数量', 'jefrssfriend'),
                    'type' => 'number',
                    'default' => 5,
                    'min' => 1,
                    'max' => 50,
                    'description' => __('每次更新时，从每个RSS源获取的最新文章数量。建议设置5-10篇，数量太大可能影响性能。', 'jefrssfriend')
                ),
                'refresh_interval' => array(
                    'title' => __('RSS刷新间隔', 'jefrssfriend'),
                    'type' => 'number',
                    'default' => 60,
                    'min' => 5,
                    'max' => 1440,
                    'description' => __('RSS源的自动刷新间隔（分钟）', 'jefrssfriend')
                ),
                'json_refresh_interval' => array(
                    'title' => __('JSON刷新间隔', 'jefrssfriend'),
                    'type' => 'number',
                    'default' => 60,
                    'min' => 5,
                    'max' => 1440,
                    'description' => __('JSON缓存文件的自动刷新间隔（分钟）', 'jefrssfriend')
                )
            )
        );
        
        // 短代码设置
        $this->settings_fields['shortcode'] = array(
            'title' => __('短代码设置', 'jefrssfriend'),
            'fields' => array(
                'latest_count' => array(
                    'title' => __('最新文章显示数量', 'jefrssfriend'),
                    'type' => 'number',
                    'default' => 100,
                    'min' => 10,
                    'max' => 1000,
                    'description' => __('短代码[jefrss_latest]显示的最新文章数量，同时也是JSON缓存的文章数量', 'jefrssfriend')
                ),
                'json_cache_time' => array(
                    'title' => __('JSON缓存更新间隔', 'jefrssfriend'),
                    'type' => 'number',
                    'default' => 3600,
                    'min' => 300,
                    'max' => 86400,
                    'description' => __('JSON缓存文件的更新间隔(秒)', 'jefrssfriend')
                ),
                'excerpt_length' => array(
                    'title' => __('摘要长度', 'jefrssfriend'),
                    'type' => 'number',
                    'default' => 150,
                    'min' => 50,
                    'max' => 500,
                    'description' => __('文章摘要显示的字数', 'jefrssfriend')
                ),
            )
        );
    }
    
    public function register_settings() {
        // 注册设置
        register_setting(
            'jefrssfriend_options',
            'jefrssfriend_options',
            array(
                'sanitize_callback' => array($this, 'sanitize_options'),
                'default' => array()
            )
        );
        
        // 基本设置
        add_settings_section(
            'jefrssfriend_basic',
            __('基本设置', 'jefrssfriend'),
            array($this, 'render_section_basic'),
            'jefrssfriend_settings'
        );
        
        // 添加设置字段
        add_settings_field(
            'articles_per_feed',
            __('每次更新获取文章数量', 'jefrssfriend'),
            array($this, 'render_field'),
            'jefrssfriend_settings',
            'jefrssfriend_basic',
            array(
                'name' => 'articles_per_feed',
                'type' => 'number',
                'unit' => '篇',
                'description' => __('每次更新时，从每个RSS源获取的最新文章数量。建议设置5-10篇，数量太大可能影响性能。', 'jefrssfriend')
            )
        );
        
        add_settings_field(
            'refresh_interval',
            __('RSS刷新间隔', 'jefrssfriend'),
            array($this, 'render_field'),
            'jefrssfriend_settings',
            'jefrssfriend_basic',
            array(
                'name' => 'refresh_interval',
                'type' => 'number',
                'description' => __('RSS源的自动刷新间隔（分钟）', 'jefrssfriend')
            )
        );
        
        add_settings_field(
            'json_refresh_interval',
            __('JSON刷新间隔', 'jefrssfriend'),
            array($this, 'render_field'),
            'jefrssfriend_settings',
            'jefrssfriend_basic',
            array(
                'name' => 'json_refresh_interval',
                'type' => 'number',
                'min' => 1,
                'max' => 1440,
                'description' => __('JSON缓存文件的自动刷新间隔（分钟）', 'jefrssfriend')
            )
        );
        
        // 添加摘要长度设置字段
        add_settings_field(
            'excerpt_length',
            __('摘要长度', 'jefrssfriend'),
            array($this, 'render_field'),
            'jefrssfriend_settings',
            'jefrssfriend_basic',
            array(
                'name' => 'excerpt_length',
                'type' => 'number',
                'min' => 50,
                'max' => 500,
                'unit' => '字',
                'description' => __('文章摘要显示的字数', 'jefrssfriend')
            )
        );
        
        // 添加图标服务商设置
        add_settings_field(
            'icon_service',
            __('图标服务商', 'jefrssfriend'),
            array($this, 'render_field'),
            'jefrssfriend_settings',
            'jefrssfriend_basic',
            array(
                'name' => 'icon_service',
                'type' => 'select',
                'options' => array(
                    'unavatar' => 'https://unavatar.io/',
                    'favicon' => 'https://favicon.im/',
                    'cravatar' => 'https://cravatar.com/favicon/api/',
                    'afmax' => 'https://api.afmax.cn/so/ico/',
                    'iconhorse' => 'https://icon.horse/icon/'
                ),
                'description' => __('选择用于获取网站图标的服务商。若前台图标不展示请切换服务商。', 'jefrssfriend')
            )
        );
        
        // 添加图标圆角设置
        add_settings_field(
            'icon_radius',
            __('图标圆角', 'jefrssfriend'),
            array($this, 'render_field'),
            'jefrssfriend_settings',
            'jefrssfriend_basic',
            array(
                'name' => 'icon_radius',
                'type' => 'number',
                'min' => 0,
                'max' => 50,
                'unit' => '%',
                'description' => __('设置图标的圆角大小，默认为5%', 'jefrssfriend')
            )
        );
    }
    
    /**
     * 渲染抓取间隔设置字段
     */
    public function render_field_fetch_interval() {
        $options = get_option('jefrssfriend_options');
        $interval = isset($options['refresh_interval']) ? intval($options['refresh_interval']) : 60;
        ?>
        <input type="number" 
               name="jefrssfriend_options[refresh_interval]" 
               value="<?php echo esc_attr($interval); ?>"
               min="5"
               max="1440"
               class="small-text">
        <?php _e('分钟', 'jefrssfriend'); ?>
        <?php
    }
    
    /**
     * 清理和验证设置值
     */
    public function sanitize_options($input) {
        $new_input = array();
        
        // 处理文章数量设置
        if (isset($input['articles_per_feed'])) {
            $new_input['articles_per_feed'] = intval($input['articles_per_feed']);
            if ($new_input['articles_per_feed'] < 1) {
                $new_input['articles_per_feed'] = 1;
            }
            if ($new_input['articles_per_feed'] > 50) {
                $new_input['articles_per_feed'] = 50;
            }
            // 同步设置缓存大小
            $new_input['cache_size'] = $new_input['articles_per_feed'];
        }
        
        // 处理RSS刷新间隔设置
        if (isset($input['refresh_interval'])) {
            $new_input['refresh_interval'] = intval($input['refresh_interval']);
            if ($new_input['refresh_interval'] < 5) {
                $new_input['refresh_interval'] = 5;
            }
            if ($new_input['refresh_interval'] > 1440) {
                $new_input['refresh_interval'] = 1440;
            }
        }
        
        // 处理JSON刷新间隔设置
        if (isset($input['json_refresh_interval'])) {
            $new_input['json_refresh_interval'] = intval($input['json_refresh_interval']);
            if ($new_input['json_refresh_interval'] < 5) {
                $new_input['json_refresh_interval'] = 5;
            }
            if ($new_input['json_refresh_interval'] > 1440) {
                $new_input['json_refresh_interval'] = 1440;
            }
        }
        
        // 处理设置更新后的定时任务
        if (isset($new_input['refresh_interval'])) {
            wp_clear_scheduled_hook('jefrssfriend_cron_refresh');
            if ($new_input['refresh_interval'] > 0) {
                wp_schedule_event(
                    time(), 
                    'jefrssfriend_interval', 
                    'jefrssfriend_cron_refresh'
                );
            }
        }
        
        // 处理摘要长度设置
        if (isset($input['excerpt_length'])) {
            $new_input['excerpt_length'] = intval($input['excerpt_length']);
            if ($new_input['excerpt_length'] < 50) {
                $new_input['excerpt_length'] = 50;
            }
            if ($new_input['excerpt_length'] > 500) {
                $new_input['excerpt_length'] = 500;
            }
        }

        // 处理图标服务商设置
        if (isset($input['icon_service'])) {
            // 验证是否是允许的服务商
            $allowed_services = array('unavatar', 'favicon', 'cravatar', 'afmax', 'iconhorse');
            $new_input['icon_service'] = in_array($input['icon_service'], $allowed_services) 
                ? $input['icon_service'] 
                : 'unavatar';
        }
        
        // 处理图标圆角设置
        if (isset($input['icon_radius'])) {
            $new_input['icon_radius'] = intval($input['icon_radius']);
            if ($new_input['icon_radius'] < 0) {
                $new_input['icon_radius'] = 0;
            }
            if ($new_input['icon_radius'] > 50) {
                $new_input['icon_radius'] = 50;
            }
        }
        
        error_log('保存的设置: ' . print_r($new_input, true));
        return $new_input;
    }
    
    /**
     * 清理缓存
     */
    private function clear_cache() {
        // 清理文章摘要缓存
        global $wpdb;
        $wpdb->query("DELETE FROM {$wpdb->options} WHERE option_name LIKE '_transient_jefrss_excerpt_%'");
        $wpdb->query("DELETE FROM {$wpdb->options} WHERE option_name LIKE '_transient_timeout_jefrss_excerpt_%'");
    }
    
    public function get_option($key, $default = false) {
        return isset($this->options[$key]) ? $this->options[$key] : $default;
    }
    
    /**
     * 渲染缓存大小字段
     */
    public function render_field_cache_size() {
        $options = get_option('jefrssfriend_options');
        $cache_size = isset($options['cache_size']) ? intval($options['cache_size']) : 10;
        ?>
        <input type="number" 
               name="jefrssfriend_options[cache_size]" 
               value="<?php echo esc_attr($cache_size); ?>"
               min="1"
               max="500"
               class="small-text">
        <p class="description">
            <?php _e('设置每个RSS源保留的最新文章数量', 'jefrssfriend'); ?>
        </p>
        <?php
    }
    
    /**
     * 渲染每个源抓取文章数字段
     */
    public function render_field_articles_per_feed() {
        $options = get_option('jefrssfriend_options');
        $articles_per_feed = isset($options['articles_per_feed']) ? intval($options['articles_per_feed']) : 1;
        ?>
        <input type="number" 
               name="jefrssfriend_options[articles_per_feed]" 
               value="<?php echo esc_attr($articles_per_feed); ?>"
               min="1"
               max="50"
               class="small-text">
        <p class="description">
            <?php _e('每个RSS源每次抓取的文章数量', 'jefrssfriend'); ?>
        </p>
        <?php
    }
    
    /**
     * 渲染基本设置区块说明
     */
    public function render_section_basic() {
        ?>
        <p class="description">
            <?php _e('基本的显示和抓取设置', 'jefrssfriend'); ?>
        </p>
        <?php
    }
    
    /**
     * 渲染JSON刷新间隔设置字段
     */
    public function render_field_json_refresh_interval() {
        $options = get_option('jefrssfriend_options');
        $interval = isset($options['json_refresh_interval']) ? intval($options['json_refresh_interval']) : 60;
        ?>
        <input type="number" 
               name="jefrssfriend_options[json_refresh_interval]" 
               value="<?php echo esc_attr($interval); ?>"
               min="5"
               max="1440"
               class="small-text">
        <?php _e('分钟', 'jefrssfriend'); ?>
        <p class="description">
            <?php _e('设置JSON缓存文件的自动刷新间隔（5-1440分钟）', 'jefrssfriend'); ?>
        </p>
        <?php
    }
    
    public function save_settings() {
        if (isset($_POST['jefrssfriend_options'])) {
            $old_options = get_option('jefrssfriend_options');
            $new_options = $_POST['jefrssfriend_options'];
            
            // 如果刷新间隔有变化
            if (isset($new_options['refresh_interval']) && 
                (!isset($old_options['refresh_interval']) || 
                 $new_options['refresh_interval'] != $old_options['refresh_interval'])) {
                
                // 清除现有的定时任务
                wp_clear_scheduled_hook('jefrssfriend_cron_refresh');
                
                // 设置新的定时任务
                $interval = intval($new_options['refresh_interval']);
                if ($interval > 0) {
                    wp_schedule_event(
                        time(), 
                        'jefrssfriend_interval', 
                        'jefrssfriend_cron_refresh'
                    );
                }
            }
            
            update_option('jefrssfriend_options', $new_options);
        }
    }
    
    /**
     * 处理维护请求
     */
    public function handle_maintenance_requests() {
        if (!isset($_POST['action'])) {
            return;
        }

        // 检查用户权限
        if (!current_user_can('manage_options')) {
            wp_die(__('您没有足够的权限执行此操作。', 'jefrssfriend'));
        }

        switch ($_POST['action']) {
            case 'cleanup_articles':
                if (check_admin_referer('jefrssfriend_cleanup', 'cleanup_nonce')) {
                    $this->cleanup_all_articles();
                }
                break;

            case 'cleanup_old_articles':
                if (check_admin_referer('jefrssfriend_cleanup_old', 'cleanup_old_nonce')) {
                    $this->cleanup_old_articles();
                }
                break;

            case 'refresh_json':
                if (check_admin_referer('jefrssfriend_refresh_json', 'refresh_json_nonce')) {
                    $this->refresh_json_cache();
                }
                break;
        }
    }
    
    /**
     * 清理所有文章
     */
    private function cleanup_all_articles() {
        global $wpdb;
        
        try {
            $result = $wpdb->query("TRUNCATE TABLE {$wpdb->prefix}jefrss_articles");
            
            if ($result !== false) {
                if (wp_doing_ajax()) {
                    // AJAX请求返回JSON响应
                    wp_send_json_success(array(
                        'message' => '所有文章已清理完成',
                        'type' => 'success'
                    ));
                } else {
                    // 常规表单提交使用 settings_errors
                    add_settings_error(
                        'jefrssfriend_messages',
                        'cleanup_success',
                        __('所有文章已清理完成', 'jefrssfriend'),
                        'success'
                    );
                }
            } else {
                throw new Exception($wpdb->last_error);
            }
        } catch (Exception $e) {
            if (wp_doing_ajax()) {
                wp_send_json_error(array(
                    'message' => '清理文章时出错：' . $e->getMessage(),
                    'type' => 'error'
                ));
            } else {
                add_settings_error(
                    'jefrssfriend_messages',
                    'cleanup_error',
                    __('清理文章时出错：', 'jefrssfriend') . $e->getMessage(),
                    'error'
                );
            }
        }
    }
    
    /**
     * 清理旧文章
     */
    private function cleanup_old_articles() {
        global $wpdb;
        
        try {
            $options = get_option('jefrssfriend_options');
            $articles_per_feed = isset($options['articles_per_feed']) ? intval($options['articles_per_feed']) : 5;
            
            $sites = $wpdb->get_results("SELECT id FROM {$wpdb->prefix}jefrss_sites WHERE status = 'active'");
            $cleaned = 0;
            
            foreach ($sites as $site) {
                $before = $wpdb->get_var($wpdb->prepare(
                    "SELECT COUNT(*) FROM {$wpdb->prefix}jefrss_articles WHERE site_id = %d",
                    $site->id
                ));
                
                // 只保留每个源最新的N篇文章
                $wpdb->query($wpdb->prepare(
                    "DELETE FROM {$wpdb->prefix}jefrss_articles 
                    WHERE site_id = %d 
                    AND id NOT IN (
                        SELECT id FROM (
                            SELECT id 
                            FROM {$wpdb->prefix}jefrss_articles 
                            WHERE site_id = %d 
                            ORDER BY pub_date DESC 
                            LIMIT %d
                        ) temp
                    )",
                    $site->id,
                    $site->id,
                    $articles_per_feed
                ));
                
                $after = $wpdb->get_var($wpdb->prepare(
                    "SELECT COUNT(*) FROM {$wpdb->prefix}jefrss_articles WHERE site_id = %d",
                    $site->id
                ));
                
                $cleaned += ($before - $after);
            }
            
            if (wp_doing_ajax()) {
                wp_send_json_success(array(
                    'message' => sprintf(__('成功清理了 %d 篇旧文章', 'jefrssfriend'), $cleaned),
                    'type' => 'success'
                ));
            } else {
                add_settings_error(
                    'jefrssfriend_messages',
                    'cleanup_success',
                    sprintf(__('成功清理了 %d 篇旧文章', 'jefrssfriend'), $cleaned),
                    'success'
                );
            }
        } catch (Exception $e) {
            if (wp_doing_ajax()) {
                wp_send_json_error(array(
                    'message' => '清理旧文章时出错：' . $e->getMessage(),
                    'type' => 'error'
                ));
            } else {
                add_settings_error(
                    'jefrssfriend_messages',
                    'cleanup_error',
                    __('清理旧文章时出错：', 'jefrssfriend') . $e->getMessage(),
                    'error'
                );
            }
        }
    }
    
    /**
     * 刷新JSON缓存
     */
    private function refresh_json_cache() {
        try {
            global $wpdb;
            
            // 1. 获取所有活跃的RSS源
            $sites = $wpdb->get_results(
                "SELECT id, title, rss_url, site_url, icon_url 
                 FROM {$wpdb->prefix}jefrss_sites 
                 WHERE status = 'active'"
            );
            
            // 2. 构建JSON数据
            $json_data = array(
                'last_update' => current_time('mysql'),
                'sites' => $sites
            );
            
            // 3. 保存到缓存文件
            $cache_file = JEFRSSFRIEND_PATH . 'cache/sites.json';
            if (!is_dir(dirname($cache_file))) {
                wp_mkdir_p(dirname($cache_file));
            }
            
            $result = file_put_contents($cache_file, json_encode($json_data, JSON_PRETTY_PRINT));
            
            if ($result === false) {
                throw new Exception('无法写入缓存文件');
            }

            if (wp_doing_ajax()) {
                wp_send_json_success(array(
                    'message' => 'JSON缓存已刷新',
                    'type' => 'success'
                ));
            }
            
            return true;
            
        } catch (Exception $e) {
            error_log('JefRSS JSON刷新错误: ' . $e->getMessage());
            if (wp_doing_ajax()) {
                wp_send_json_error(array(
                    'message' => '刷新失败：' . $e->getMessage(),
                    'type' => 'error'
                ));
            }
            return false;
        }
    }
    
    /**
     * 渲染设置页面
     */
    public function render_settings_page() {
        // 包含设置页面模板
        require_once JEFRSSFRIEND_PATH . 'admin/views/settings-page.php';
    }
    
    /**
     * 修改设置页面的间隔选项
     */
    public function render_interval_field() {
        $interval = isset($this->options['refresh_interval']) ? 
                    intval($this->options['refresh_interval']) : 60;
        ?>
        <input type="number" 
               name="jefrssfriend_options[refresh_interval]" 
               value="<?php echo esc_attr($interval); ?>"
               min="5"
               max="1440"
               class="small-text">
        <?php _e('分钟', 'jefrssfriend'); ?>
        <?php
    }
    
    public function add_cron_interval($schedules) {
        $interval = isset($this->options['refresh_interval']) ? 
                    intval($this->options['refresh_interval']) : 60;
                    
        $schedules['jefrssfriend_interval'] = array(
            'interval' => $interval * 60,
            'display' => sprintf(__('每 %d 分钟', 'jefrssfriend'), $interval)
        );
        
        return $schedules;
    }
    
    /**
     * 渲染通用字段
     */
    public function render_field($args) {
        $name = $args['name'];
        $type = $args['type'];
        $description = isset($args['description']) ? $args['description'] : '';
        $unit = isset($args['unit']) ? $args['unit'] : '';
        
        $value = isset($this->options[$name]) ? $this->options[$name] : '';
        
        switch ($type) {
            case 'number':
                ?>
                <input type="number" 
                       name="jefrssfriend_options[<?php echo esc_attr($name); ?>]" 
                       value="<?php echo esc_attr($value); ?>"
                       min="<?php echo isset($args['min']) ? esc_attr($args['min']) : '0'; ?>"
                       max="<?php echo isset($args['max']) ? esc_attr($args['max']) : ''; ?>"
                       class="small-text">
                <?php echo esc_html($unit); ?>
                <?php if ($description): ?>
                    <p class="description"><?php echo esc_html($description); ?></p>
                <?php endif; ?>
                <?php
                break;
                
            case 'select':
                ?>
                <select name="jefrssfriend_options[<?php echo esc_attr($name); ?>]">
                    <?php foreach ($args['options'] as $key => $label): ?>
                        <option value="<?php echo esc_attr($key); ?>" <?php selected($value, $key); ?>>
                            <?php echo esc_html($label); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
                <?php if ($description): ?>
                    <p class="description"><?php echo esc_html($description); ?></p>
                <?php endif; ?>
                <?php
                break;
                
            default:
                ?>
                <input type="text" 
                       name="jefrssfriend_options[<?php echo esc_attr($name); ?>]" 
                       value="<?php echo esc_attr($value); ?>"
                       class="regular-text">
                <?php if ($description): ?>
                    <p class="description"><?php echo esc_html($description); ?></p>
                <?php endif; ?>
                <?php
                break;
        }
    }
    
    public function render_refresh_interval_field() {
        $options = get_option('jefrssfriend_options');
        $value = isset($options['refresh_interval']) ? $options['refresh_interval'] : 60;
        ?>
        <input type="number" 
               name="jefrssfriend_options[refresh_interval]" 
               value="<?php echo esc_attr($value); ?>" 
               min="1" 
               max="1000" 
               class="small-text">
        <?php _e('篇', 'jefrssfriend'); ?>
        <p class="description">
            <?php _e('设置每次更新时获取的最新文章数量', 'jefrssfriend'); ?>
        </p>
        <?php
    }
    
    public function render_language_settings() {
        $current_lang = get_option('jefrssfriend_language', 'en_US');
        ?>
        <select name="jefrssfriend_language">
            <option value="zh_CN" <?php selected($current_lang, 'zh_CN'); ?>>简体中文</option>
            <option value="zh_TW" <?php selected($current_lang, 'zh_TW'); ?>>繁體中文</option>
            <option value="en_US" <?php selected($current_lang, 'en_US'); ?>>English (US)</option>
            <option value="en_GB" <?php selected($current_lang, 'en_GB'); ?>>English (UK)</option>
            <option value="ja" <?php selected($current_lang, 'ja'); ?>>日本語</option>
            <option value="ko_KR" <?php selected($current_lang, 'ko_KR'); ?>>한국어</option>
            <!-- 其他语言选项 -->
        </select>
        <?php
    }
} 